@@ -12,15 +12,11 @@ from typing import (
     cast,
 )
 
-try:
-    import orjson as json
-except ImportError:  # pragma: no cover
-    import json  # type: ignore
-
 import pydantic
 
 import ormar  # noqa: I100, I202
 from ormar.exceptions import ModelPersistenceError
+from ormar.fields.parsers import encode_json
 from ormar.models.mixins import AliasMixin
 from ormar.models.mixins.relation_mixin import RelationMixin
 
@@ -60,7 +56,6 @@ class SavePrepareMixin(RelationMixin, AliasMixin):
         new_kwargs = cls.substitute_models_with_pks(new_kwargs)
         new_kwargs = cls.populate_default_values(new_kwargs)
         new_kwargs = cls.reconvert_str_to_bytes(new_kwargs)
-        new_kwargs = cls.dump_all_json_fields_to_str(new_kwargs)
         new_kwargs = cls.translate_columns_to_aliases(new_kwargs)
         return new_kwargs
 
@@ -207,8 +202,8 @@ class SavePrepareMixin(RelationMixin, AliasMixin):
         :rtype: Dict
         """
         for key, value in model_dict.items():
-            if key in cls._json_fields and not isinstance(value, str):
-                model_dict[key] = json.dumps(value)
+            if key in cls._json_fields:
+                model_dict[key] = encode_json(value)
         return model_dict
 
     @classmethod
