@@ -22,19 +22,16 @@ from typing import (
 import databases
 import pydantic
 import sqlalchemy
-from ormar.models.utils import Extra
-from pydantic import BaseModel
 
-try:
-    import orjson as json
-except ImportError:  # pragma: no cover
-    import json  # type: ignore
+
+from pydantic import BaseModel
 
 
 import ormar  # noqa I100
 from ormar.exceptions import ModelError, ModelPersistenceError
 from ormar.fields import BaseField
 from ormar.fields.foreign_key import ForeignKeyField
+from ormar.fields.parsers import encode_json
 from ormar.models.helpers import register_relation_in_alias_manager
 from ormar.models.helpers.relations import expand_reverse_relationship
 from ormar.models.helpers.sqlalchemy import (
@@ -43,6 +40,7 @@ from ormar.models.helpers.sqlalchemy import (
 )
 from ormar.models.metaclass import ModelMeta, ModelMetaclass
 from ormar.models.modelproxy import ModelTableProxy
+from ormar.models.utils import Extra
 from ormar.queryset.utils import translate_list_to_dict
 from ormar.relations.alias_manager import AliasManager
 from ormar.relations.relation_manager import RelationsManager
@@ -912,7 +910,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
             return base64.b64encode(value).decode()
         return value
 
-    def _convert_json(self, column_name: str, value: Any) -> Union[str, Dict]:
+    def _convert_json(self, column_name: str, value: Any) -> Union[str, Dict, None]:
         """
         Converts value to/from json if needed (for Json columns).
 
@@ -925,12 +923,7 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         """
         if column_name not in self._json_fields:
             return value
-        if not isinstance(value, str):
-            try:
-                value = json.dumps(value)
-            except TypeError:  # pragma no cover
-                pass
-        return value.decode("utf-8") if isinstance(value, bytes) else value
+        return encode_json(value)
 
     def _extract_own_model_fields(self) -> Dict:
         """
